@@ -1,6 +1,6 @@
 package Algorithm::Easing::Circular;
 
-use Moo;
+use Moose;
 
 use Math::Complex;
 use Math::Trig qw(:pi);
