@@ -1,6 +1,6 @@
 package Algorithm::Easing::Ease;
 
-use Moo;
+use Moose;
 
 use constant EPSILON => 0.000001;
 
@@ -50,7 +50,7 @@ Algorithm::Easing::Ease - This is the base class for an ease.
         Return :
             p = position,
             
-        my $p = $obj->ease_both($t,$b,$c,$d);
+        my $p = $obj->ease_none($t,$b,$c,$d);
 
 This method is used for a linear translation between two positive real whole integers using a positive real integer as the parameter for time.
 
