@@ -1,6 +1,6 @@
 package Algorithm::Easing::Sinusoidal;
 
-use Moo;
+use Moose;
 
 use Math::Trig qw(:pi);
 
